<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :bottomOffset="250"
        :ajaxFun="ajaxFun"
        ref="adjustDetailTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>

<script>
import ttable from '@/views/common/ztt-table.vue'
import { delObj, fetchList } from '@/api/warehouse/adjustdetail'
import TableForm from './adjustdetail-form'
import { mapGetters } from 'vuex'
import { adjustPerform } from '../../../api/warehouse/adjustdetail'
import { loadLocation } from '../../../api/warehouse/location'

export default {
  data() {
    return {
      locations: [],
      ajaxFun: fetchList,
      multipleSelection: [],
      mulLocation: [],
      isShowQuery: false,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'adjTime', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 调整单号
          {
            minWidth: '140',
            prop: 'adjNo',
            label: '调整单号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          // 原零件号
          {
            minWidth: '120',
            prop: 'fromPartNo',
            label: '原零件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 原零件名称
          {
            minWidth: '200',
            prop: 'fromPartDesc',
            label: '原零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 原批次号
          {
            minWidth: '140',
            prop: 'fromPartBatchNo',
            label: '原批次号',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 原零件号单位
          {
            minWidth: '140',
            prop: 'unit',
            label: '原零件号单位',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 新零件号
          {
            minWidth: '120',
            prop: 'toPartNo',
            label: '新零件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 新零件名称
          {
            minWidth: '140',
            prop: 'toPartDesc',
            label: '新零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 新批次号
          {
            minWidth: '120',
            prop: 'toPartBatchNo',
            label: '新批次号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 新零件号单位
          {
            minWidth: '140',
            prop: 'units',
            label: '新零件号单位',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 从库位
          {
            minWidth: '200',
            prop: 'formLoc',
            label: '从库位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.getWarehouseStock,
            optList: () => {
              return this.locations
            }
          },
          // 到库位
          {
            minWidth: '140',
            prop: 'toLoc',
            label: '到库位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.getWarehouseStock,
            optList: () => {
              return this.locations
            }
          },
          // 调整数量
          {
            minWidth: '120',
            prop: 'adjNum',
            label: '调整数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 调整时间
          {
            minWidth: '140',
            width: '200',
            prop: 'adjTime',
            label: '调整时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          },
          // 调整类型
          {
            minWidth: '120',
            prop: 'adjType',
            label: '调整类型',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 调整状态
          {
            minWidth: '120',
            prop: 'status',
            label: '调整状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle,
            permitArr: []
          },
          {
            text: '执行',
            fun: this.adjustPerformed,
            disabled: this.disabled,
            permitArr: ['未提交']
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle,
            show: {
              val: ['未提交'],
              key: 'status'
            }
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 200,
          minWidth: 100
        }
      },
      addOrUpdateVisible: false
    }
  },
  components: {
    TableForm,
    ttable
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  mounted() {
    this.initLocationSelect()
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.adjustDetailTable.getDataList()
    },
    // 获取库位的数据
    initLocationSelect() {
      loadLocation().then((res) => {
        this.locations = JSON.parse(
          JSON.stringify(res.data.data)
            .replace(/locName/g, 'value')
            .replace(/locNo/g, 'label')
        )
      })
    },
    // 将id进行匹配显示为对应的库位名称
    getWarehouseStock(row, column, cellValue) {
      this.locations.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    handleSelectionChange(val) {
      // 根据状态，禁用表头按钮
      // 筛选出选中记录的状态
      var stateArr = val.map(function(value, index) {
        return value.status
      })
      // 选中状态数组元素去重
      var uniqueStateArr = []
      for (var i = 0; i < stateArr.length; i++) {
        if (uniqueStateArr.indexOf(stateArr[i]) == -1) {
          uniqueStateArr.push(stateArr[i])
        }
      }
      // 循环表头按钮，判断每个按钮的permitArr是否完全包含选中状态，若完全包含，则按钮亮，否则按钮灰
      var toolbar = this.table.toolbar
      for (var j = 0; j < toolbar.length; j++) {
        if (
          uniqueStateArr.every((val) =>
            toolbar[j].permitArr.length <= 0
              ? true
              : toolbar[j].permitArr.includes(val)
          )
        ) {
          toolbar[j].disabled = false
        } else {
          toolbar[j].disabled = true
        }
      }
      // 将选中记录赋值给multipleSelection
      this.multipleSelection = val
    },
    adjustPerformed() {
      if (this.multipleSelection.length == 0) {
        this.$message.success('请选择调整单号')
        return
      }
      adjustPerform(
        this.multipleSelection.map((item) => {
          return item.id
        })
      ).then((response) => {
        this.$message.success('执行成功')
        this.getData()
      })
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除调整编号为：' + row.adjNo, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    }
  }
}
</script>
